"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const ws_1 = require("./ws");
let retries = 0;
let maxRetries = 10;
const socket = function initSocket(url, handlers, reconnect) {
    let client = (0, ws_1.createWebSocketClient)(url);
    client.onOpen(() => {
        retries = 0;
        if (typeof reconnect !== "undefined") {
            maxRetries = reconnect;
        }
    });
    client.onClose(() => {
        if (retries === 0) {
            handlers.close();
        }
        client = null;
        if (retries < maxRetries) {
            const retryInMs = 1000 * Math.pow(2, retries) + Math.random() * 100;
            retries += 1;
            console.info("Trying to reconnect...");
            setTimeout(() => {
                socket(url, handlers, reconnect);
            }, retryInMs);
        }
    });
    client.onMessage((data) => {
        const message = JSON.parse(data);
        if (handlers[message.type]) {
            handlers[message.type](message.data, message.params);
        }
    });
};
exports.default = socket;
//# sourceMappingURL=socket.js.map